@@ -4,7 +4,7 @@ from .pure import *
 
 def version():
     """
-    * 2021/3/14
+    * 2021/6/1
     - [pypi_url](https://pypi.org/project/bddjango/)
 
     # 2.2
@@ -25,8 +25,15 @@ def version():
         - 将`remove_temp_file`迁移至.pure中      # 2.3.1
         - 将adminclass中的导入导出类增加权限验证和自定义取消功能
         - 将adminclass中的导出action增加取消功能       # 2.3.2
+    # 2.4 贵州图书馆项目
+        - `get_base_serializer`增加`auto_generate_annotate_fields`功能
+        - 修复了`run_list_filter`中的`annotate`字段检索失效的问题
+        - `AutoWiki`增加mac兼容
+        - BaseListView的retrieve修复queryset中annotate字段失效问题
+        - 修复get_base_serializer在queryset进行values后annotate字段失效问题
+        - 修复get_key_from_query_dc_or_self当query_dc中有False时返回值出错的bug
     """
-    v = "2.3.2"     # 正式版: 2.3.2
+    v = "2.4.0"
     return v
 
 
