@@ -42,6 +42,8 @@ import sys
 from .conf import PAGINATION_SETTINGS
 from django.db import models as m
 from django.db import connection
+from copy import deepcopy
+# from rest_framework import serializers
 
 
 def get_list(query_dc, key):
@@ -57,6 +59,31 @@ def get_list(query_dc, key):
     return ret
 
 
+def get_key_from_request_data_or_self_obj(request_data, self_obj, key, get_type=None):
+    """
+    优先检索request_data是否有key, 其次检索self_obj是否有key这个属性
+    :param key: 变量名
+    :return:
+    """
+    query_dc = request_data
+
+    if get_type == 'list':
+        value = get_list(query_dc, key)
+    elif get_type == 'bool':
+        value = query_dc.get(key)
+        ret_0 = getattr(self_obj, key) if hasattr(self_obj, key) else None
+        ret_1 = pure.convert_query_parameter_to_bool(value) if value else None
+        ret = ret_1 if ret_1 is not None else ret_0
+        return ret
+    else:
+        value = query_dc.get(key)
+
+    # 让request携带的数据可以覆盖自身的key值
+    ret_0 = getattr(self_obj, key) if hasattr(self_obj, key) else None
+    ret = value if value is not None else ret_0
+    return ret
+
+
 def set_query_dc_value(query_dc: QueryDict, new_dc: dict):
     query_dc._mutable = True
     for key, value in new_dc.items():
@@ -66,22 +93,84 @@ def set_query_dc_value(query_dc: QueryDict, new_dc: dict):
     return query_dc
 
 
-def get_base_serializer(base_model, base_fields='__all__'):
+def get_base_serializer(base_model, base_fields='__all__', auto_generate_annotate_fields=None):
     """
     生成一个基础序列化器
 
     :param base_model: queryset或者base_model
-    :param base_fields: 字段
+    :param base_fields: 想要返回的字段
+    :param auto_generate_annotate_fields: 指定将自动生成的annotate的字段, 为[True, '__all__']时自动替换为base_fields
     :return:
     """
     base_model = get_base_model(base_model)
 
-    class BaseSerializer(s.ModelSerializer):
-        class Meta:
-            model = base_model
-            fields = base_fields
-    base_serializer = BaseSerializer
-    return base_serializer
+    if not pure.convert_query_parameter_to_bool(auto_generate_annotate_fields):
+        class BaseSerializer(s.ModelSerializer):
+            class Meta:
+                model = base_model
+                fields = base_fields
+
+        base_serializer = BaseSerializer
+        return base_serializer
+    else:
+        if auto_generate_annotate_fields is True or auto_generate_annotate_fields in ['__all__', ['__all__']]:
+            auto_generate_annotate_fields = base_fields
+        elif isinstance(auto_generate_annotate_fields, str):
+            auto_generate_annotate_fields = [auto_generate_annotate_fields]
+
+        field_names = [dc.name for dc in base_model._meta.fields]
+
+        # --- 这里要把queryset里有, 但model.fields里没有的字段在serializers时自动加上
+        new_dc_ls = []
+        new_func_ls = []
+        for field in base_fields:
+            if field not in field_names and field in auto_generate_annotate_fields:
+                # 指定方法字段 SerializerMethodField 后, 再增加 get_field_function.
+                field_method = s.SerializerMethodField()
+                new_func_name = f'get_{field}'
+
+                def get_field_value(self, obj):
+                    ret = None
+                    k_name = getattr(self, '__field_name__')
+                    if hasattr(obj, k_name):
+                        ret = getattr(obj, k_name)
+                    elif isinstance(obj, dict) and k_name in obj:
+                        ret = obj.get(k_name)
+                    else:
+                        msg = f'自动生成的[{k_name}]字段值为空! --- from get_base_serializer'
+                        warn(msg)
+                    return ret
+
+                new_func_cls = {
+                    '__field_name__': field,
+                    new_func_name: get_field_value,
+                }
+                new_func_cls = type("new_func_cls", (object,), new_func_cls)
+                new_func = getattr(new_func_cls(), new_func_name)
+
+                new_dc_i = {
+                    field: field_method,
+                }
+                new_func_i = {
+                    new_func_name: new_func,
+                }
+                new_dc_ls.append(new_dc_i)
+                new_func_ls.append(new_func_i)
+
+        # --- 生成新序列化器base_serializer
+        meta_dc = {
+            'model': base_model,
+            'fields': base_fields
+        }
+        Meta = type("Meta", (object,), meta_dc)
+        cls_dc = {
+            'Meta': Meta,
+        }
+        for i in range(len(new_dc_ls)):
+            cls_dc.update(new_dc_ls[i])
+            cls_dc.update(new_func_ls[i])
+        base_serializer = type("BaseSerializer", (s.ModelSerializer,), cls_dc)
+        return base_serializer
 
 
 def judge_is_obj_level_of_request(request):
